@@ -1344,7 +1344,7 @@ def profile_max_tw_day_hourly_visualization(data):
 	plt.plot(x,y)
 
 	
-def sentiental_analysis_features(data):
+def sentimental_analysis_features(data):
 	corpus =[]
 	polarities=[]
 	subjectivities=[]
@@ -1763,6 +1763,20 @@ def graph_json_values_telegram(df_connections, data_graph_structure):
     return data
 
 ###----------------------Contextual Analysis Telegram -----------------------###
+
+def messages_preprocessing(msg, nodes_participants_dict):
+    l=[]
+    for i in range(len(msg)):
+        l.append(msg.from_id.iloc[i]['user_id'])
+    msg['sender_id'] = l
+    msg["screen_name"] = ""
+    for i in range(len(msg)):
+        try:
+            msg["screen_name"].iloc[i] = nodes_participants_dict[msg["sender_id"].iloc[i]]
+        except:
+            msg["screen_name"].iloc[i] = "This ID Left the group"
+    return msg
+
 def detectLanguge(msg):
     lan=[]
     for i in range(len(msg)):
@@ -1856,13 +1870,40 @@ def hashtags_content_similarity(msg, corpus):
     msg['hashtags_terrorist_similarity'] = l
     return msg
 
-def contextual_analysis_telegram(messages, corpus):
+def contextual_analysis_telegram(messages, node_dict,corpus):
+    messages = messages_preprocessing(messages, node_dict)
     messages = detectLanguge(messages)
     messages = translateToEnglish(messages)
     messages = detect_hastags(messages)
     messages = hastags_preprocessing(messages)
-    messages = content_similitarity(messages, corpus)
+    messages = content_similitarity(messages,corpus)
     messages = hashtags_content_similarity(messages, corpus)
+    messages = sentimental_analysis_telegram(messages)
     return messages
 
-   
+def sentimental_analysis_telegram(data):    
+    data = sentimental_analysis_features(data)
+    data["terrorist_suggestion"] = 0
+    data["terrorist_suggestion"][(data["terrorist_content_similarity"]>3) | (data["hashtags_terrorist_similarity"]>0)] = 1
+    data["terrorist_suggestion"][(data["terrorist_suggestion"]==1) & (data["polarity"] <= -0.1) & (data["subjectivity"]>=0.6)]= "Negative opinion"
+    data["terrorist_suggestion"][(data["terrorist_suggestion"]==1) & (data["polarity"] <= -0.1) & (data["subjectivity"]<0.6)]= "Negative fact"
+    data["terrorist_suggestion"][(data["terrorist_suggestion"]==1) & (data["polarity"] < 0.1) & (data["polarity"] > -0.1)]= "Neutral"
+    data["terrorist_suggestion"][(data["terrorist_suggestion"]==1) & (data["polarity"] >= 0.1) & (data["subjectivity"]<=0.5)]= "Positive opinion"
+    data["terrorist_suggestion"][(data["terrorist_suggestion"]==1) & (data["polarity"] >= 0.1) & (data["subjectivity"]>0.5)]= "Positive opinion"
+    data["terrorist_suggestion"][(data["terrorist_suggestion"]==0)] = "Don´talk about terrorism" 
+    return data
+
+def sentimental_analysis_features(data):
+	corpus =[]
+	polarities=[]
+	subjectivities=[]
+	for tweet in data.translated_message:
+		corpus.append(TextBlob(tweet.lower()))
+	for i in range(len(corpus)):
+		polarities.append(corpus[i].polarity)
+		subjectivities.append(corpus[i].subjectivity)
+	data['polarity']= polarities
+	data['subjectivity']= subjectivities
+	return data
+
+
